@@ -1,12 +1,8 @@
-extern crate lambda_runtime as lambda;
-extern crate log;
-extern crate serde_derive;
-extern crate simple_logger;
-extern crate tokio;
-
-use lambda::{error::HandlerError, lambda};
-use log::error;
+use lambda_runtime::{error::HandlerError, lambda, Context};
+use log::{self, error};
 use serde_derive::{Deserialize, Serialize};
+use simple_error::bail;
+use simple_logger;
 use std::error::Error;
 use tokio::runtime::Runtime;
 
@@ -24,16 +20,16 @@ struct CustomOutput {
 fn main() -> Result<(), Box<dyn Error>> {
     let rt = Runtime::new()?;
 
-    simple_logger::init_with_level(log::Level::Debug).unwrap();
+    simple_logger::init_with_level(log::Level::Debug)?;
     lambda!(my_handler, rt);
 
     Ok(())
 }
 
-fn my_handler(e: CustomEvent, c: lambda::Context) -> Result<CustomOutput, HandlerError> {
+fn my_handler(e: CustomEvent, c: Context) -> Result<CustomOutput, HandlerError> {
     if e.first_name == "" {
         error!("Empty first name in request {}", c.aws_request_id);
-        return Err(c.new_error("Empty first name"));
+        bail!("Empty first name");
     }
 
     Ok(CustomOutput {
